	"ERRNO_0", /* 0 */
	"EPERM", /* 1 */
	"ENOENT", /* 2 */
	"ESRCH", /* 3 */
	"EINTR", /* 4 */
	"EIO", /* 5 */
	"ENXIO", /* 6 */
	"E2BIG", /* 7 */
	"ENOEXEC", /* 8 */
	"EBADF", /* 9 */
	"ECHILD", /* 10 */
	"EAGAIN", /* 11 */
	"ENOMEM", /* 12 */
	"EACCES", /* 13 */
	"EFAULT", /* 14 */
	"ENOTBLK", /* 15 */
	"EBUSY", /* 16 */
	"EEXIST", /* 17 */
	"EXDEV", /* 18 */
	"ENODEV", /* 19 */
	"ENOTDIR", /* 20 */
	"EISDIR", /* 21 */
	"EINVAL", /* 22 */
	"ENFILE", /* 23 */
	"EMFILE", /* 24 */
	"ENOTTY", /* 25 */
	"ETXTBSY", /* 26 */
	"EFBIG", /* 27 */
	"ENOSPC", /* 28 */
	"ESPIPE", /* 29 */
	"EROFS", /* 30 */
	"EMLINK", /* 31 */
	"EPIPE", /* 32 */
	"EDOM", /* 33 */
	"ERANGE", /* 34 */
	"EDEADLK", /* 35 */
	"ENAMETOOLONG", /* 36 */
	"ENOLCK", /* 37 */
	"ENOSYS", /* 38 */
	"ENOTEMPTY", /* 39 */
	"ELOOP", /* 40 */
	"ERRNO_41", /* 41 */
	"ENOMSG", /* 42 */
	"EIDRM", /* 43 */
	"ECHRNG", /* 44 */
	"EL2NSYNC", /* 45 */
	"EL3HLT", /* 46 */
	"EL3RST", /* 47 */
	"ELNRNG", /* 48 */
	"EUNATCH", /* 49 */
	"ENOCSI", /* 50 */
	"EL2HLT", /* 51 */
	"EBADE", /* 52 */
	"EBADR", /* 53 */
	"EXFULL", /* 54 */
	"ENOANO", /* 55 */
	"EBADRQC", /* 56 */
	"EBADSLT", /* 57 */
#ifdef POWERPC
	"EDEADLOCK", /* 58 */
#else
	"ERRNO_58", /* 58 */
#endif
	"EBFONT", /* 59 */
	"ENOSTR", /* 60 */
	"ENODATA", /* 61 */
	"ETIME", /* 62 */
	"ENOSR", /* 63 */
	"ENONET", /* 64 */
	"ENOPKG", /* 65 */
	"EREMOTE", /* 66 */
	"ENOLINK", /* 67 */
	"EADV", /* 68 */
	"ESRMNT", /* 69 */
	"ECOMM", /* 70 */
	"EPROTO", /* 71 */
	"EMULTIHOP", /* 72 */
	"EDOTDOT", /* 73 */
	"EBADMSG", /* 74 */
	"EOVERFLOW", /* 75 */
	"ENOTUNIQ", /* 76 */
	"EBADFD", /* 77 */
	"EREMCHG", /* 78 */
	"ELIBACC", /* 79 */
	"ELIBBAD", /* 80 */
	"ELIBSCN", /* 81 */
	"ELIBMAX", /* 82 */
	"ELIBEXEC", /* 83 */
	"EILSEQ", /* 84 */
	"ERESTART", /* 85 */
	"ESTRPIPE", /* 86 */
	"EUSERS", /* 87 */
	"ENOTSOCK", /* 88 */
	"EDESTADDRREQ", /* 89 */
	"EMSGSIZE", /* 90 */
	"EPROTOTYPE", /* 91 */
	"ENOPROTOOPT", /* 92 */
	"EPROTONOSUPPORT", /* 93 */
	"ESOCKTNOSUPPORT", /* 94 */
	"EOPNOTSUPP", /* 95 */
	"EPFNOSUPPORT", /* 96 */
	"EAFNOSUPPORT", /* 97 */
	"EADDRINUSE", /* 98 */
	"EADDRNOTAVAIL", /* 99 */
	"ENETDOWN", /* 100 */
	"ENETUNREACH", /* 101 */
	"ENETRESET", /* 102 */
	"ECONNABORTED", /* 103 */
	"ECONNRESET", /* 104 */
	"ENOBUFS", /* 105 */
	"EISCONN", /* 106 */
	"ENOTCONN", /* 107 */
	"ESHUTDOWN", /* 108 */
	"ETOOMANYREFS", /* 109 */
	"ETIMEDOUT", /* 110 */
	"ECONNREFUSED", /* 111 */
	"EHOSTDOWN", /* 112 */
	"EHOSTUNREACH", /* 113 */
	"EALREADY", /* 114 */
	"EINPROGRESS", /* 115 */
	"ESTALE", /* 116 */
	"EUCLEAN", /* 117 */
	"ENOTNAM", /* 118 */
	"ENAVAIL", /* 119 */
	"EISNAM", /* 120 */
	"EREMOTEIO", /* 121 */
	"EDQUOT", /* 122 */
	"ENOMEDIUM", /* 123 */
	"EMEDIUMTYPE", /* 124 */
	"ECANCELED", /* 125 */
	"ENOKEY", /* 126 */
	"EKEYEXPIRED", /* 127 */
	"EKEYREVOKED", /* 128 */
	"EKEYREJECTED", /* 129 */
	"EOWNERDEAD", /* 130 */
	"ENOTRECOVERABLE", /* 131 */
	"ERFKILL", /* 132 */
	"ERRNO_133", /* 133 */
	"ERRNO_134", /* 134 */
	"ERRNO_135", /* 135 */
	"ERRNO_136", /* 136 */
	"ERRNO_137", /* 137 */
	"ERRNO_138", /* 138 */
	"ERRNO_139", /* 139 */
	"ERRNO_140", /* 140 */
	"ERRNO_141", /* 141 */
	"ERRNO_142", /* 142 */
	"ERRNO_143", /* 143 */
	"ERRNO_144", /* 144 */
	"ERRNO_145", /* 145 */
	"ERRNO_146", /* 146 */
	"ERRNO_147", /* 147 */
	"ERRNO_148", /* 148 */
	"ERRNO_149", /* 149 */
	"ERRNO_150", /* 150 */
	"ERRNO_151", /* 151 */
	"ERRNO_152", /* 152 */
	"ERRNO_153", /* 153 */
	"ERRNO_154", /* 154 */
	"ERRNO_155", /* 155 */
	"ERRNO_156", /* 156 */
	"ERRNO_157", /* 157 */
	"ERRNO_158", /* 158 */
	"ERRNO_159", /* 159 */
	"ERRNO_160", /* 160 */
	"ERRNO_161", /* 161 */
	"ERRNO_162", /* 162 */
	"ERRNO_163", /* 163 */
	"ERRNO_164", /* 164 */
	"ERRNO_165", /* 165 */
	"ERRNO_166", /* 166 */
	"ERRNO_167", /* 167 */
	"ERRNO_168", /* 168 */
	"ERRNO_169", /* 169 */
	"ERRNO_170", /* 170 */
	"ERRNO_171", /* 171 */
	"ERRNO_172", /* 172 */
	"ERRNO_173", /* 173 */
	"ERRNO_174", /* 174 */
	"ERRNO_175", /* 175 */
	"ERRNO_176", /* 176 */
	"ERRNO_177", /* 177 */
	"ERRNO_178", /* 178 */
	"ERRNO_179", /* 179 */
	"ERRNO_180", /* 180 */
	"ERRNO_181", /* 181 */
	"ERRNO_182", /* 182 */
	"ERRNO_183", /* 183 */
	"ERRNO_184", /* 184 */
	"ERRNO_185", /* 185 */
	"ERRNO_186", /* 186 */
	"ERRNO_187", /* 187 */
	"ERRNO_188", /* 188 */
	"ERRNO_189", /* 189 */
	"ERRNO_190", /* 190 */
	"ERRNO_191", /* 191 */
	"ERRNO_192", /* 192 */
	"ERRNO_193", /* 193 */
	"ERRNO_194", /* 194 */
	"ERRNO_195", /* 195 */
	"ERRNO_196", /* 196 */
	"ERRNO_197", /* 197 */
	"ERRNO_198", /* 198 */
	"ERRNO_199", /* 199 */
	"ERRNO_200", /* 200 */
	"ERRNO_201", /* 201 */
	"ERRNO_202", /* 202 */
	"ERRNO_203", /* 203 */
	"ERRNO_204", /* 204 */
	"ERRNO_205", /* 205 */
	"ERRNO_206", /* 206 */
	"ERRNO_207", /* 207 */
	"ERRNO_208", /* 208 */
	"ERRNO_209", /* 209 */
	"ERRNO_210", /* 210 */
	"ERRNO_211", /* 211 */
	"ERRNO_212", /* 212 */
	"ERRNO_213", /* 213 */
	"ERRNO_214", /* 214 */
	"ERRNO_215", /* 215 */
	"ERRNO_216", /* 216 */
	"ERRNO_217", /* 217 */
	"ERRNO_218", /* 218 */
	"ERRNO_219", /* 219 */
	"ERRNO_220", /* 220 */
	"ERRNO_221", /* 221 */
	"ERRNO_222", /* 222 */
	"ERRNO_223", /* 223 */
	"ERRNO_224", /* 224 */
	"ERRNO_225", /* 225 */
	"ERRNO_226", /* 226 */
	"ERRNO_227", /* 227 */
	"ERRNO_228", /* 228 */
	"ERRNO_229", /* 229 */
	"ERRNO_230", /* 230 */
	"ERRNO_231", /* 231 */
	"ERRNO_232", /* 232 */
	"ERRNO_233", /* 233 */
	"ERRNO_234", /* 234 */
	"ERRNO_235", /* 235 */
	"ERRNO_236", /* 236 */
	"ERRNO_237", /* 237 */
	"ERRNO_238", /* 238 */
	"ERRNO_239", /* 239 */
	"ERRNO_240", /* 240 */
	"ERRNO_241", /* 241 */
	"ERRNO_242", /* 242 */
	"ERRNO_243", /* 243 */
	"ERRNO_244", /* 244 */
	"ERRNO_245", /* 245 */
	"ERRNO_246", /* 246 */
	"ERRNO_247", /* 247 */
	"ERRNO_248", /* 248 */
	"ERRNO_249", /* 249 */
	"ERRNO_250", /* 250 */
	"ERRNO_251", /* 251 */
	"ERRNO_252", /* 252 */
	"ERRNO_253", /* 253 */
	"ERRNO_254", /* 254 */
	"ERRNO_255", /* 255 */
	"ERRNO_256", /* 256 */
	"ERRNO_257", /* 257 */
	"ERRNO_258", /* 258 */
	"ERRNO_259", /* 259 */
	"ERRNO_260", /* 260 */
	"ERRNO_261", /* 261 */
	"ERRNO_262", /* 262 */
	"ERRNO_263", /* 263 */
	"ERRNO_264", /* 264 */
	"ERRNO_265", /* 265 */
	"ERRNO_266", /* 266 */
	"ERRNO_267", /* 267 */
	"ERRNO_268", /* 268 */
	"ERRNO_269", /* 269 */
	"ERRNO_270", /* 270 */
	"ERRNO_271", /* 271 */
	"ERRNO_272", /* 272 */
	"ERRNO_273", /* 273 */
	"ERRNO_274", /* 274 */
	"ERRNO_275", /* 275 */
	"ERRNO_276", /* 276 */
	"ERRNO_277", /* 277 */
	"ERRNO_278", /* 278 */
	"ERRNO_279", /* 279 */
	"ERRNO_280", /* 280 */
	"ERRNO_281", /* 281 */
	"ERRNO_282", /* 282 */
	"ERRNO_283", /* 283 */
	"ERRNO_284", /* 284 */
	"ERRNO_285", /* 285 */
	"ERRNO_286", /* 286 */
	"ERRNO_287", /* 287 */
	"ERRNO_288", /* 288 */
	"ERRNO_289", /* 289 */
	"ERRNO_290", /* 290 */
	"ERRNO_291", /* 291 */
	"ERRNO_292", /* 292 */
	"ERRNO_293", /* 293 */
	"ERRNO_294", /* 294 */
	"ERRNO_295", /* 295 */
	"ERRNO_296", /* 296 */
	"ERRNO_297", /* 297 */
	"ERRNO_298", /* 298 */
	"ERRNO_299", /* 299 */
	"ERRNO_300", /* 300 */
	"ERRNO_301", /* 301 */
	"ERRNO_302", /* 302 */
	"ERRNO_303", /* 303 */
	"ERRNO_304", /* 304 */
	"ERRNO_305", /* 305 */
	"ERRNO_306", /* 306 */
	"ERRNO_307", /* 307 */
	"ERRNO_308", /* 308 */
	"ERRNO_309", /* 309 */
	"ERRNO_310", /* 310 */
	"ERRNO_311", /* 311 */
	"ERRNO_312", /* 312 */
	"ERRNO_313", /* 313 */
	"ERRNO_314", /* 314 */
	"ERRNO_315", /* 315 */
	"ERRNO_316", /* 316 */
	"ERRNO_317", /* 317 */
	"ERRNO_318", /* 318 */
	"ERRNO_319", /* 319 */
	"ERRNO_320", /* 320 */
	"ERRNO_321", /* 321 */
	"ERRNO_322", /* 322 */
	"ERRNO_323", /* 323 */
	"ERRNO_324", /* 324 */
	"ERRNO_325", /* 325 */
	"ERRNO_326", /* 326 */
	"ERRNO_327", /* 327 */
	"ERRNO_328", /* 328 */
	"ERRNO_329", /* 329 */
	"ERRNO_330", /* 330 */
	"ERRNO_331", /* 331 */
	"ERRNO_332", /* 332 */
	"ERRNO_333", /* 333 */
	"ERRNO_334", /* 334 */
	"ERRNO_335", /* 335 */
	"ERRNO_336", /* 336 */
	"ERRNO_337", /* 337 */
	"ERRNO_338", /* 338 */
	"ERRNO_339", /* 339 */
	"ERRNO_340", /* 340 */
	"ERRNO_341", /* 341 */
	"ERRNO_342", /* 342 */
	"ERRNO_343", /* 343 */
	"ERRNO_344", /* 344 */
	"ERRNO_345", /* 345 */
	"ERRNO_346", /* 346 */
	"ERRNO_347", /* 347 */
	"ERRNO_348", /* 348 */
	"ERRNO_349", /* 349 */
	"ERRNO_350", /* 350 */
	"ERRNO_351", /* 351 */
	"ERRNO_352", /* 352 */
	"ERRNO_353", /* 353 */
	"ERRNO_354", /* 354 */
	"ERRNO_355", /* 355 */
	"ERRNO_356", /* 356 */
	"ERRNO_357", /* 357 */
	"ERRNO_358", /* 358 */
	"ERRNO_359", /* 359 */
	"ERRNO_360", /* 360 */
	"ERRNO_361", /* 361 */
	"ERRNO_362", /* 362 */
	"ERRNO_363", /* 363 */
	"ERRNO_364", /* 364 */
	"ERRNO_365", /* 365 */
	"ERRNO_366", /* 366 */
	"ERRNO_367", /* 367 */
	"ERRNO_368", /* 368 */
	"ERRNO_369", /* 369 */
	"ERRNO_370", /* 370 */
	"ERRNO_371", /* 371 */
	"ERRNO_372", /* 372 */
	"ERRNO_373", /* 373 */
	"ERRNO_374", /* 374 */
	"ERRNO_375", /* 375 */
	"ERRNO_376", /* 376 */
	"ERRNO_377", /* 377 */
	"ERRNO_378", /* 378 */
	"ERRNO_379", /* 379 */
	"ERRNO_380", /* 380 */
	"ERRNO_381", /* 381 */
	"ERRNO_382", /* 382 */
	"ERRNO_383", /* 383 */
	"ERRNO_384", /* 384 */
	"ERRNO_385", /* 385 */
	"ERRNO_386", /* 386 */
	"ERRNO_387", /* 387 */
	"ERRNO_388", /* 388 */
	"ERRNO_389", /* 389 */
	"ERRNO_390", /* 390 */
	"ERRNO_391", /* 391 */
	"ERRNO_392", /* 392 */
	"ERRNO_393", /* 393 */
	"ERRNO_394", /* 394 */
	"ERRNO_395", /* 395 */
	"ERRNO_396", /* 396 */
	"ERRNO_397", /* 397 */
	"ERRNO_398", /* 398 */
	"ERRNO_399", /* 399 */
	"ERRNO_400", /* 400 */
	"ERRNO_401", /* 401 */
	"ERRNO_402", /* 402 */
	"ERRNO_403", /* 403 */
	"ERRNO_404", /* 404 */
	"ERRNO_405", /* 405 */
	"ERRNO_406", /* 406 */
	"ERRNO_407", /* 407 */
	"ERRNO_408", /* 408 */
	"ERRNO_409", /* 409 */
	"ERRNO_410", /* 410 */
	"ERRNO_411", /* 411 */
	"ERRNO_412", /* 412 */
	"ERRNO_413", /* 413 */
	"ERRNO_414", /* 414 */
	"ERRNO_415", /* 415 */
	"ERRNO_416", /* 416 */
	"ERRNO_417", /* 417 */
	"ERRNO_418", /* 418 */
	"ERRNO_419", /* 419 */
	"ERRNO_420", /* 420 */
	"ERRNO_421", /* 421 */
	"ERRNO_422", /* 422 */
	"ERRNO_423", /* 423 */
	"ERRNO_424", /* 424 */
	"ERRNO_425", /* 425 */
	"ERRNO_426", /* 426 */
	"ERRNO_427", /* 427 */
	"ERRNO_428", /* 428 */
	"ERRNO_429", /* 429 */
	"ERRNO_430", /* 430 */
	"ERRNO_431", /* 431 */
	"ERRNO_432", /* 432 */
	"ERRNO_433", /* 433 */
	"ERRNO_434", /* 434 */
	"ERRNO_435", /* 435 */
	"ERRNO_436", /* 436 */
	"ERRNO_437", /* 437 */
	"ERRNO_438", /* 438 */
	"ERRNO_439", /* 439 */
	"ERRNO_440", /* 440 */
	"ERRNO_441", /* 441 */
	"ERRNO_442", /* 442 */
	"ERRNO_443", /* 443 */
	"ERRNO_444", /* 444 */
	"ERRNO_445", /* 445 */
	"ERRNO_446", /* 446 */
	"ERRNO_447", /* 447 */
	"ERRNO_448", /* 448 */
	"ERRNO_449", /* 449 */
	"ERRNO_450", /* 450 */
	"ERRNO_451", /* 451 */
	"ERRNO_452", /* 452 */
	"ERRNO_453", /* 453 */
	"ERRNO_454", /* 454 */
	"ERRNO_455", /* 455 */
	"ERRNO_456", /* 456 */
	"ERRNO_457", /* 457 */
	"ERRNO_458", /* 458 */
	"ERRNO_459", /* 459 */
	"ERRNO_460", /* 460 */
	"ERRNO_461", /* 461 */
	"ERRNO_462", /* 462 */
	"ERRNO_463", /* 463 */
	"ERRNO_464", /* 464 */
	"ERRNO_465", /* 465 */
	"ERRNO_466", /* 466 */
	"ERRNO_467", /* 467 */
	"ERRNO_468", /* 468 */
	"ERRNO_469", /* 469 */
	"ERRNO_470", /* 470 */
	"ERRNO_471", /* 471 */
	"ERRNO_472", /* 472 */
	"ERRNO_473", /* 473 */
	"ERRNO_474", /* 474 */
	"ERRNO_475", /* 475 */
	"ERRNO_476", /* 476 */
	"ERRNO_477", /* 477 */
	"ERRNO_478", /* 478 */
	"ERRNO_479", /* 479 */
	"ERRNO_480", /* 480 */
	"ERRNO_481", /* 481 */
	"ERRNO_482", /* 482 */
	"ERRNO_483", /* 483 */
	"ERRNO_484", /* 484 */
	"ERRNO_485", /* 485 */
	"ERRNO_486", /* 486 */
	"ERRNO_487", /* 487 */
	"ERRNO_488", /* 488 */
	"ERRNO_489", /* 489 */
	"ERRNO_490", /* 490 */
	"ERRNO_491", /* 491 */
	"ERRNO_492", /* 492 */
	"ERRNO_493", /* 493 */
	"ERRNO_494", /* 494 */
	"ERRNO_495", /* 495 */
	"ERRNO_496", /* 496 */
	"ERRNO_497", /* 497 */
	"ERRNO_498", /* 498 */
	"ERRNO_499", /* 499 */
	"ERRNO_500", /* 500 */
	"ERRNO_501", /* 501 */
	"ERRNO_502", /* 502 */
	"ERRNO_503", /* 503 */
	"ERRNO_504", /* 504 */
	"ERRNO_505", /* 505 */
	"ERRNO_506", /* 506 */
	"ERRNO_507", /* 507 */
	"ERRNO_508", /* 508 */
	"ERRNO_509", /* 509 */
	"ERRNO_510", /* 510 */
	"ERRNO_511", /* 511 */
	"ERESTARTSYS", /* 512 */
	"ERESTARTNOINTR", /* 513 */
	"ERESTARTNOHAND", /* 514 */
	"ENOIOCTLCMD", /* 515 */
	"ERESTART_RESTARTBLOCK", /* 516 */
	"ERRNO_517", /* 517 */
	"ERRNO_518", /* 518 */
	"ERRNO_519", /* 519 */
	"ERRNO_520", /* 520 */
	"EBADHANDLE", /* 521 */
	"ENOTSYNC", /* 522 */
	"EBADCOOKIE", /* 523 */
	"ENOTSUPP", /* 524 */
	"ETOOSMALL", /* 525 */
	"ESERVERFAULT", /* 526 */
	"EBADTYPE", /* 527 */
	"EJUKEBOX", /* 528 */
	"EIOCBQUEUED", /* 529 */
	"EIOCBRETRY", /* 530 */
